summaryrefslogtreecommitdiffstats
path: root/net/base/cookie_store.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/base/cookie_store.h')
-rw-r--r--net/base/cookie_store.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/net/base/cookie_store.h b/net/base/cookie_store.h
index 3572d51..b1dd5ab 100644
--- a/net/base/cookie_store.h
+++ b/net/base/cookie_store.h
@@ -10,6 +10,7 @@
#include <string>
#include "base/basictypes.h"
+#include "base/ref_counted.h"
#include "base/time.h"
#include "net/base/cookie_options.h"
@@ -20,8 +21,8 @@ namespace net {
class CookieMonster;
// An interface for storing and retrieving cookies. Implementations need to
-// be therad safe as its methods can be accessed from IO as well as UI threads.
-class CookieStore {
+// be thread safe as its methods can be accessed from IO as well as UI threads.
+class CookieStore : public base::RefCountedThreadSafe<CookieStore> {
public:
virtual ~CookieStore() {}